(function ($, Drupal, drupalSettings, once) {

  let config = {
    chart: {
      height: 600,
      inverted: true
    },
    title: {
      text: Drupal.t('Organization Chart')
    },
    accessibility: {
      point: {
        descriptionFormatter: function (point) {
          var nodeName = point.toNode.name,
            nodeId = point.toNode.id,
            nodeDesc = nodeName === nodeId ? nodeName : nodeName + ', ' + nodeId,
            parentDesc = point.fromNode.id;
          return point.index + '. ' + nodeDesc + ', reports to ' + parentDesc + '.';
        }
      }
    },
    series: [{
      type: 'organization',
      keys: ['from', 'to'],
      colorByPoint: false,
      color: '#007ad0',
      dataLabels: {
        color: 'white'
      },
      borderColor: 'white',
      nodeWidth: 65
    }],
    tooltip: {
      outside: true
    },
    exporting: {
      allowHTML: true,
      sourceWidth: 800,
      sourceHeight: 600
    }
  };
  Drupal.behaviors.organization = {
    attach: function attach(context) {
      $(once('organization', ".views-view-organization", context))
        .each(function () {
          let id = $(this).attr('id');
          config.series[0].levels = drupalSettings[id].levels;
          config.series[0].nodes = drupalSettings[id].nodes;
          config.series[0].data = drupalSettings[id].data;
          config.series[0].name = drupalSettings[id].title;
          config.title.text = drupalSettings[id].title;
          Highcharts.chart(id, config);
        });
    }
  };
}(jQuery, Drupal, drupalSettings, once));
